@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     DomainType,
@@ -26,29 +26,29 @@ from .literals import (
 )
 from .paginator import ListServersPaginator
 from .type_defs import (
-    CreateAccessResponseResponseTypeDef,
-    CreateServerResponseResponseTypeDef,
-    CreateUserResponseResponseTypeDef,
-    DescribeAccessResponseResponseTypeDef,
-    DescribeSecurityPolicyResponseResponseTypeDef,
-    DescribeServerResponseResponseTypeDef,
-    DescribeUserResponseResponseTypeDef,
+    CreateAccessResponseTypeDef,
+    CreateServerResponseTypeDef,
+    CreateUserResponseTypeDef,
+    DescribeAccessResponseTypeDef,
+    DescribeSecurityPolicyResponseTypeDef,
+    DescribeServerResponseTypeDef,
+    DescribeUserResponseTypeDef,
     EndpointDetailsTypeDef,
     HomeDirectoryMapEntryTypeDef,
     IdentityProviderDetailsTypeDef,
-    ImportSshPublicKeyResponseResponseTypeDef,
-    ListAccessesResponseResponseTypeDef,
-    ListSecurityPoliciesResponseResponseTypeDef,
-    ListServersResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
-    ListUsersResponseResponseTypeDef,
+    ImportSshPublicKeyResponseTypeDef,
+    ListAccessesResponseTypeDef,
+    ListSecurityPoliciesResponseTypeDef,
+    ListServersResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    ListUsersResponseTypeDef,
     PosixProfileTypeDef,
     ProtocolDetailsTypeDef,
     TagTypeDef,
-    TestIdentityProviderResponseResponseTypeDef,
-    UpdateAccessResponseResponseTypeDef,
-    UpdateServerResponseResponseTypeDef,
-    UpdateUserResponseResponseTypeDef,
+    TestIdentityProviderResponseTypeDef,
+    UpdateAccessResponseTypeDef,
+    UpdateServerResponseTypeDef,
+    UpdateUserResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -81,20 +81,25 @@ class Exceptions:
     ThrottlingException: Type[BotocoreClientError]
 
 
-class TransferClient:
+class TransferClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        TransferClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#can_paginate)
         """
 
@@ -109,13 +114,13 @@ class TransferClient:
         HomeDirectoryMappings: List["HomeDirectoryMapEntryTypeDef"] = None,
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None
-    ) -> CreateAccessResponseResponseTypeDef:
+    ) -> CreateAccessResponseTypeDef:
         """
         Used by administrators to choose which groups in the directory should have
         access to upload and download files over the enabled protocols using Amazon Web
         Services Transfer Family.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.create_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_access)
         """
 
@@ -133,12 +138,12 @@ class TransferClient:
         Protocols: List[ProtocolType] = None,
         SecurityPolicyName: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateServerResponseResponseTypeDef:
+    ) -> CreateServerResponseTypeDef:
         """
         Instantiates an auto-scaling virtual server based on the selected file transfer
         protocol in Amazon Web Services.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.create_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_server)
         """
 
@@ -155,12 +160,12 @@ class TransferClient:
         PosixProfile: "PosixProfileTypeDef" = None,
         SshPublicKeyBody: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateUserResponseResponseTypeDef:
+    ) -> CreateUserResponseTypeDef:
         """
         Creates a user and associates them with an existing file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#create_user)
         """
 
@@ -169,7 +174,7 @@ class TransferClient:
         Allows you to delete the access specified in the `ServerID` and `ExternalID`
         parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.delete_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_access)
         """
 
@@ -177,7 +182,7 @@ class TransferClient:
         """
         Deletes the file transfer protocol-enabled server that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.delete_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_server)
         """
 
@@ -185,7 +190,7 @@ class TransferClient:
         """
         Deletes a user's Secure Shell (SSH) public key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.delete_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_ssh_public_key)
         """
 
@@ -194,47 +199,45 @@ class TransferClient:
         Deletes the user belonging to a file transfer protocol-enabled server you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#delete_user)
         """
 
-    def describe_access(
-        self, *, ServerId: str, ExternalId: str
-    ) -> DescribeAccessResponseResponseTypeDef:
+    def describe_access(self, *, ServerId: str, ExternalId: str) -> DescribeAccessResponseTypeDef:
         """
         Describes the access that is assigned to the specific file transfer protocol-
         enabled server, as identified by its `ServerId` property and its `ExternalID` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.describe_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_access)
         """
 
     def describe_security_policy(
         self, *, SecurityPolicyName: str
-    ) -> DescribeSecurityPolicyResponseResponseTypeDef:
+    ) -> DescribeSecurityPolicyResponseTypeDef:
         """
         Describes the security policy that is attached to your file transfer protocol-
         enabled server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_security_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.describe_security_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_security_policy)
         """
 
-    def describe_server(self, *, ServerId: str) -> DescribeServerResponseResponseTypeDef:
+    def describe_server(self, *, ServerId: str) -> DescribeServerResponseTypeDef:
         """
         Describes a file transfer protocol-enabled server that you specify by passing
         the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.describe_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_server)
         """
 
-    def describe_user(self, *, ServerId: str, UserName: str) -> DescribeUserResponseResponseTypeDef:
+    def describe_user(self, *, ServerId: str, UserName: str) -> DescribeUserResponseTypeDef:
         """
         Describes the user assigned to the specific file transfer protocol-enabled
         server, as identified by its `ServerId` property.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.describe_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.describe_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#describe_user)
         """
 
@@ -248,73 +251,73 @@ class TransferClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#generate_presigned_url)
         """
 
     def import_ssh_public_key(
         self, *, ServerId: str, SshPublicKeyBody: str, UserName: str
-    ) -> ImportSshPublicKeyResponseResponseTypeDef:
+    ) -> ImportSshPublicKeyResponseTypeDef:
         """
         Adds a Secure Shell (SSH) public key to a user account identified by a
         `UserName` value assigned to the specific file transfer protocol-enabled server,
         identified by `ServerId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.import_ssh_public_key)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#import_ssh_public_key)
         """
 
     def list_accesses(
         self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListAccessesResponseResponseTypeDef:
+    ) -> ListAccessesResponseTypeDef:
         """
         Lists the details for all the accesses you have on your server.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_accesses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.list_accesses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_accesses)
         """
 
     def list_security_policies(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListSecurityPoliciesResponseResponseTypeDef:
+    ) -> ListSecurityPoliciesResponseTypeDef:
         """
         Lists the security policies that are attached to your file transfer protocol-
         enabled servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_security_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.list_security_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_security_policies)
         """
 
     def list_servers(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListServersResponseResponseTypeDef:
+    ) -> ListServersResponseTypeDef:
         """
         Lists the file transfer protocol-enabled servers that are associated with your
         Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.list_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_servers)
         """
 
     def list_tags_for_resource(
         self, *, Arn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    ) -> ListTagsForResourceResponseTypeDef:
         """
         Lists all of the tags associated with the Amazon Resource Name (ARN) that you
         specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_tags_for_resource)
         """
 
     def list_users(
         self, *, ServerId: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListUsersResponseResponseTypeDef:
+    ) -> ListUsersResponseTypeDef:
         """
         Lists the users for a file transfer protocol-enabled server that you specify by
         passing the `ServerId` parameter.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.list_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.list_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#list_users)
         """
 
@@ -323,7 +326,7 @@ class TransferClient:
         Changes the state of a file transfer protocol-enabled server from `OFFLINE` to
         `ONLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.start_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.start_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#start_server)
         """
 
@@ -332,7 +335,7 @@ class TransferClient:
         Changes the state of a file transfer protocol-enabled server from `ONLINE` to
         `OFFLINE`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.stop_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.stop_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#stop_server)
         """
 
@@ -341,7 +344,7 @@ class TransferClient:
         Attaches a key-value pair to a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#tag_resource)
         """
 
@@ -353,13 +356,13 @@ class TransferClient:
         ServerProtocol: ProtocolType = None,
         SourceIp: str = None,
         UserPassword: str = None
-    ) -> TestIdentityProviderResponseResponseTypeDef:
+    ) -> TestIdentityProviderResponseTypeDef:
         """
         If the `IdentityProviderType` of a file transfer protocol-enabled server is
         `AWS_DIRECTORY_SERVICE` or `API_Gateway` , tests whether your identity provider
         is set up successfully.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.test_identity_provider)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.test_identity_provider)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#test_identity_provider)
         """
 
@@ -368,7 +371,7 @@ class TransferClient:
         Detaches a key-value pair from a resource, as identified by its Amazon Resource
         Name (ARN).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#untag_resource)
         """
 
@@ -383,12 +386,12 @@ class TransferClient:
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
-    ) -> UpdateAccessResponseResponseTypeDef:
+    ) -> UpdateAccessResponseTypeDef:
         """
         Allows you to update parameters for the access specified in the `ServerID` and
         `ExternalID` parameters.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_access)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.update_access)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_access)
         """
 
@@ -405,12 +408,12 @@ class TransferClient:
         LoggingRole: str = None,
         Protocols: List[ProtocolType] = None,
         SecurityPolicyName: str = None
-    ) -> UpdateServerResponseResponseTypeDef:
+    ) -> UpdateServerResponseTypeDef:
         """
         Updates the file transfer protocol-enabled server's properties after that server
         has been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.update_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_server)
         """
 
@@ -425,16 +428,16 @@ class TransferClient:
         Policy: str = None,
         PosixProfile: "PosixProfileTypeDef" = None,
         Role: str = None
-    ) -> UpdateUserResponseResponseTypeDef:
+    ) -> UpdateUserResponseTypeDef:
         """
         Assigns new properties to a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/client.html#update_user)
         """
 
     def get_paginator(self, operation_name: Literal["list_servers"]) -> ListServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/transfer.html#Transfer.Paginator.ListServers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/transfer.html#Transfer.Paginator.ListServers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_transfer/paginators.html#listserverspaginator)
         """
